package Task::DualLived;

use 5.005;
our $VERSION = '0.05';

1;
__END__

=head1 NAME

Task::DualLived - Perl extension for updating dual-lived modules

=head1 SYNOPSIS

  perl Makefile.PL
  make
  make test
  make install

=head1 DESCRIPTION

  updates all core dual-lived modules

=head1 SEE ALSO

  Bundle::dualLived
  App::DualLivedList
  App::DualLivedDiff

=head1 AUTHOR

  Kevin W. Henwood, <Khen1950fx@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.005 or,
at your option, any later version of Perl 5 you may have available.

=cut
